Module styled

Module styled 

Multi-style layout: baseline-aligned layout across StyledRuns.

LayoutEngine::layout_styled_runs accepts a slice of pre-shaped StyledRuns each with its own font metrics and pixel size, and positions them so that all glyphs on the same line share a common baseline. The common baseline is determined by the maximum ascender among all runs contributing to that line (UAX #14-aware greedy line-breaking is applied first).

Structs

StyledRun
A pre-shaped run of glyphs with its own font metrics and pixel size.