Hyphenation support: soft-hyphen detection and automatic hyphenation.
Provides two complementary break-opportunity sources:
-
soft_hyphen_breaksscans the input text for U+00AD SOFT HYPHEN and returns the byte offset after each soft-hyphen character (i.e. the start of the next character). This offset is where the line may be broken, which is the same convention used byunicode-linebreakand the layout engine’s internal break-opportunity list. -
[
automatic_hyphen_breaks] (behind thehyphenationfeature) uses TeX hyphenation patterns via the [hypher] crate to find additional break opportunities within words for the given language.
Functions
- soft_
hyphen_ breaks - Scan
textfor U+00AD SOFT HYPHEN characters and return the byte offset after each one.